@@ -2,6 +2,8 @@ import os
 import uuid
 import json
 import base64
+import tempfile
+import zipfile
 from io import BytesIO
 
 import werkzeug
@@ -23,32 +25,36 @@ def upload_dataset():
     if 'dataset' not in request.files:
         return jsonify({'status': 'dataset is empty'}), 400
 
-    # save file
-    file = request.files['dataset']
-    file_name = werkzeug.utils.secure_filename(file.filename)
-    file_path = os.path.join(get_config('UPLOAD_DIR'), file_name)
-    file.save(file_path)
+    # save uploaded files and create MDPDataset
+    with tempfile.TemporaryDirectory() as dname:
+        # save file
+        file = request.files['dataset']
+        file_name = werkzeug.utils.secure_filename(file.filename)
+        file_path = os.path.join(dname, file_name)
+        file.save(file_path)
 
-    # save as MDPDataset
-    is_image = request.form.get('is_image') == 'true'
-    is_discrete = request.form.get('is_discrete') == 'true'
+        # save image files
+        is_image = request.form.get('is_image') == 'true'
+        if is_image:
+            # save zip file
+            zip_file = request.files['zip_file']
+            zip_file_name = werkzeug.utils.secure_filename(zip_file.filename)
+            zip_file_path = os.path.join(dname, zip_file_name)
+            zip_file.save(zip_file_path)
+            # decompress zip file
+            with zipfile.ZipFile(zip_file_path) as zip_fd:
+                zip_fd.extractall(dname)
 
-    # save image files
-    if is_image:
-        total_images = int(request.form.get('total_images'))
-        for i in range(total_images):
-            image_file = request.files['image_%d' % i]
-            image_name = os.path.basename(image_file.filename)
-            image_name = werkzeug.utils.secure_filename(image_name)
-            image_path = os.path.join(get_config('UPLOAD_DIR'), image_name)
-            image_file.save(image_path)
+        # convert uploaded data to MDPDataset
+        try:
+            mdp_dataset = import_csv_as_mdp_dataset(file_path, image=is_image)
+        except ValueError:
+            return jsonify({'status': 'dataset conversion failed.'}), 400
 
-    mdp_dataset = import_csv_as_mdp_dataset(file_path,
-                                            image=is_image,
-                                            discrete_action=is_discrete)
-    dataset_name = str(uuid.uuid1()) + '.h5'
-    dataset_path = os.path.join(get_config('DATASET_DIR'), dataset_name)
-    mdp_dataset.dump(dataset_path)
+        # save MDPDataset object.
+        dataset_name = str(uuid.uuid1()) + '.h5'
+        dataset_path = os.path.join(get_config('DATASET_DIR'), dataset_name)
+        mdp_dataset.dump(dataset_path)
 
     # get dataset size
     data_size = os.path.getsize(dataset_path)
@@ -64,7 +70,8 @@ def upload_dataset():
 
     # insert record
     dataset = Dataset.create(file_name, dataset_name, episode_size, step_size,
-                             data_size, is_image, is_discrete, stats_json)
+                             data_size, is_image,
+                             mdp_dataset.is_action_discrete(), stats_json)
 
     # return json
     return jsonify(DatasetSchema().dump(dataset))
