@@ -9,6 +9,7 @@ from flask.json import JSONEncoder
 
 import minerva.models
 import minerva.database as database
+from minerva._version import __version__
 from minerva.config import DATABASE_PATH, ROOT_DIR, MIGRATION_DIR
 from minerva.config import config, prepare_directory
 from minerva.database import init_db, db
@@ -64,28 +65,33 @@ def send_file(path):
 
 @click.group()
 def cli():
-    pass
+    print("MINERVA command line interface (Version %s)" % __version__)
 
 
 @cli.command(short_help='Start MINERVA server.')
 @click.option('--host', '-h', default='0.0.0.0', help='Host IP address.')
 @click.option('--port', '-p', default=9000, help='Port number.')
-def run(host, port):
+@click.option("--debug", is_flag=True, help="Start as debug mode.")
+def run(host, port, debug):
     # create databse if not exists
     if not os.path.exists(DATABASE_PATH):
         with app.app_context():
             db.create_all()
             database.init_migration(MIGRATION_DIR)
             database.create_migration(MIGRATION_DIR)
+        print('Database initialization has been completed.')
 
     # start server
-    app.run(debug=True, host=host, port=int(port))
+    app.run(debug=debug, host=host, port=int(port))
 
 
 @cli.command(short_help='Initialize database.')
 def create_db():
     with app.app_context():
         db.create_all()
+        database.init_migration(MIGRATION_DIR)
+        database.create_migration(MIGRATION_DIR)
+    print('Database initialization has been completed.')
 
 
 @cli.command(short_help='Upgrade database schema.')
@@ -93,17 +99,21 @@ def upgrade_db():
     with app.app_context():
         database.create_migration(MIGRATION_DIR)
         database.upgrade_db(MIGRATION_DIR)
+    print('Database migration has been completed.')
 
 
 @cli.command(short_help='Rollback database schema.')
 def downgrade_db():
     with app.app_context():
         database.downgrade_db(MIGRATION_DIR)
+    print('Database rollback has been completed.')
 
 
 @cli.command(short_help='Delete all data from the disk.')
 def clean():
+    print(f'{ROOT_DIR} is being deleted...')
     shutil.rmtree(ROOT_DIR)
+    print(f'{ROOT_DIR} has been deleted.')
 
 
 if __name__ == '__main__':
